==> tuia-advert-center-api-1.5.9-20180715.063316-5-sources.jar: cn/com/duiba/tuia/core/api/dto/statistics/AdvertDataByHourDto.java <==
package cn.com.duiba.tuia.core.api.dto.statistics;

import cn.com.duiba.tuia.core.api.statistics.domain.AdvertStatisticsData;

import java.util.Date;

/**
 * Created by huangch on 2017/8/29 11:52
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertDataByHourDto extends AdvertStatisticsData {

    private static final long serialVersionUID = -5568562119061719009L;

    /**
     * 统计时间.
     */
    private int time;

    /**
     * 统计时间段.
     */
    private String timeBucket;

    /**
     * The billing count.
     */
    private Long billingCount;

    /**
     * The billing price.
     */
    private Long billingPrice;

    /**
     * 兑吧优惠券ID.
     */
    private Long itemId;

    /**
     * 当前日期.
     */
    private Date curDate;

    public int getTime() {
        return time;
    }

    public void setTime(int time) {
        this.time = time;
    }

    public String getTimeBucket() {
        return timeBucket;
    }

    public void setTimeBucket(String timeBucket) {
        this.timeBucket = timeBucket;
    }

    public Long getBillingCount() {
        return billingCount;
    }

    public void setBillingCount(Long billingCount) {
        this.billingCount = billingCount;
    }

    public Long getBillingPrice() {
        return billingPrice;
    }

    public void setBillingPrice(Long billingPrice) {
        this.billingPrice = billingPrice;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }
}

==> tuia-advert-center-api-2.6.27-sources.jar: cn/com/duiba/tuia/core/api/dto/statistics/AdvertDataByHourDto.java <==
package cn.com.duiba.tuia.core.api.dto.statistics;

import cn.com.duiba.tuia.core.api.statistics.domain.AdvertStatisticsData;

import java.math.BigDecimal;
import java.util.Date;

/**
 * Created by huangch on 2017/8/29 11:52
 * description:
 *
 * @since JDK 1.6
 */
public class AdvertDataByHourDto extends AdvertStatisticsData {

    private static final long serialVersionUID = -5568562119061719009L;

    /**
     * 统计时间.
     */
    private int time;

    /**
     * 统计时间段.
     */
    private String timeBucket;

    /**
     * The billing count.
     */
    private Long billingCount;

    /**
     * The billing price.
     */
    private Long billingPrice;

    /**
     * 兑吧优惠券ID.
     */
    private Long itemId;

    /**
     * 当前日期.
     */
    private Date curDate;

    /**
     * 付款金额
     */
    private BigDecimal paymentAmount;

    public BigDecimal getPaymentAmount() {
        return paymentAmount;
    }

    public void setPaymentAmount(BigDecimal paymentAmount) {
        this.paymentAmount = paymentAmount;
    }

    public int getTime() {
        return time;
    }

    public void setTime(int time) {
        this.time = time;
    }

    public String getTimeBucket() {
        return timeBucket;
    }

    public void setTimeBucket(String timeBucket) {
        this.timeBucket = timeBucket;
    }

    public Long getBillingCount() {
        return billingCount;
    }

    public void setBillingCount(Long billingCount) {
        this.billingCount = billingCount;
    }

    public Long getBillingPrice() {
        return billingPrice;
    }

    public void setBillingPrice(Long billingPrice) {
        this.billingPrice = billingPrice;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }
}
